import 'package:flutter/material.dart';

typedef ActionTap = Future<void> Function();

class PQBottomSheetAction<T> {
  /// 文本
  final String? text;

  /// 背景色
  final Color? color;

  /// 文本颜色
  final Color? textColor;

  /// 文本大小
  final double? fontSize;

  /// 文字字重
  final FontWeight? fontWeight;

  /// 点击事件
  final ActionTap? onTap;
  final T? Function(PQBottomSheetAction model)? result;

  /// 分割线颜色 default is `Color(0xFFF0F0F0)1
  final Color dividerLineColor;

  /// 按钮高度 默认是 56
  final EdgeInsetsGeometry? padding;

  /// 是否自动消失，默认是true
  final bool autoPop;

  final int? maxLines;

  PQBottomSheetAction._(
    this.text, {
    this.color,
    this.textColor,
    this.fontWeight,
    this.fontSize,
    this.onTap,
    this.result,
    this.padding,
        this.maxLines,
    this.autoPop = true,
    this.dividerLineColor = const Color(0xFFF0F0F0),
  });

  factory PQBottomSheetAction.custom(String? text,
          {Color? color,
          Color? textColor,
          FontWeight? fontWeight,
          double? fontSize,
          ActionTap? onTap,
          EdgeInsetsGeometry? padding = const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
          bool autoPop = true,
          Color? dividerLineColor,
            int? maxLines,
          T? Function(PQBottomSheetAction model)? result}) =>
      PQBottomSheetAction._(text,
          color: color,
          textColor: textColor,
          fontWeight: fontWeight,
          fontSize: fontSize,
          onTap: onTap,
          padding: padding,
          autoPop: autoPop,
          dividerLineColor: dividerLineColor ?? Color(0xFFF0F0F0),
          maxLines: maxLines,
          result: result);

  factory PQBottomSheetAction.normal(String? text,
          {Color? color = Colors.transparent,
          Color? textColor = const Color(0xFF666666),
          double? fontSize,
          FontWeight? fontWeight = FontWeight.normal,
          ActionTap? onTap,
          EdgeInsetsGeometry? padding = const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
          bool autoPop = true,
          Color? dividerLineColor,
            int? maxLines,
          T? Function(PQBottomSheetAction model)? result}) =>
      PQBottomSheetAction._(text,
          color: color,
          textColor: textColor,
          fontWeight: fontWeight,
          fontSize: fontSize,
          onTap: onTap,
          padding: padding,
          autoPop: autoPop,
          dividerLineColor: dividerLineColor ?? Color(0xFFF0F0F0),
          maxLines: maxLines,
          result: result);

  factory PQBottomSheetAction.highlight(String? text,
          {Color? color = Colors.transparent,
          Color? textColor = const Color(0xFFF25555),
          double? fontSize,
          FontWeight? fontWeight = FontWeight.normal,
          ActionTap? onTap,
          EdgeInsetsGeometry? padding = const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
          bool autoPop = true,
          Color? dividerLineColor,
            int? maxLines,
          T? Function(PQBottomSheetAction model)? result}) =>
      PQBottomSheetAction._(text,
          color: color,
          textColor: textColor,
          fontWeight: fontWeight,
          fontSize: fontSize,
          onTap: onTap,
          padding: padding,
          autoPop: autoPop,
          dividerLineColor: dividerLineColor ?? Color(0xFFF0F0F0),
          maxLines: maxLines,
          result: result);

  factory PQBottomSheetAction.cancel(
          {String? text = "放弃",
          Color? color = Colors.transparent,
          Color? textColor = const Color(0xFF666666),
          double? fontSize,
          FontWeight? fontWeight = FontWeight.normal,
          ActionTap? onTap,
          EdgeInsetsGeometry? padding = const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
          bool autoPop = true,
          Color? dividerLineColor,
            int? maxLines,
          T? Function(PQBottomSheetAction model)? result}) =>
      PQBottomSheetAction._(text,
          color: color,
          textColor: textColor,
          fontWeight: fontWeight,
          fontSize: fontSize,
          onTap: onTap,
          padding: padding,
          autoPop: autoPop,
          dividerLineColor: dividerLineColor ?? Color(0xFFF0F0F0),
          maxLines: maxLines,
          result: result);
}
