import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import '../../pq_widgets.dart';
import 'bottom_sheet_action.dart';

abstract class PQDialog {
  static void dismiss<T>(BuildContext context, {T? result}) {
    final navigator = Navigator.of(context);
    bool canPop = navigator.canPop();
    if (canPop) {
      navigator.pop(result);
    }
  }

  static Future<T?> show<T>({
    required BuildContext context,
    required WidgetBuilder builder,
    bool barrierDismissible = true,
    Color? barrierColor = Colors.black54,
    String? barrierLabel,
    bool useSafeArea = true,
    bool useRootNavigator = true,
    RouteSettings? routeSettings,
  }) {
    return showDialog(
        context: context,
        builder: builder,
        barrierDismissible: barrierDismissible,
        barrierColor: barrierColor,
        barrierLabel: barrierLabel,
        useSafeArea: useSafeArea,
        useRootNavigator: useRootNavigator,
        routeSettings: routeSettings);
  }

  /// 显示底部按钮区域，使用bottom sheet的形式
  static Future showBottomSheetByActions(
    context, {
    required List<PQBottomSheetAction> actions,
    Color? backgroundColor = Colors.white,
    double? elevation,
    Clip? clipBehavior,
    Color? barrierColor,
    bool isScrollControlled = false,
    bool useRootNavigator = false,
    bool isDismissible = true,
    bool enableDrag = true,
    RouteSettings? routeSettings,
    AnimationController? transitionAnimationController,
    ShapeBorder? shape = const RoundedRectangleBorder(
      borderRadius: BorderRadius.vertical(top: Radius.circular(16.0)),
    ),
  }) async {
    List<Widget> children = [];
    double height = 0.0;
    actions.forEach((e) {
      // height += e.height;
      children.add(CupertinoButton(
        onPressed: e.onTap == null ? null : () async {
          await e.onTap?.call();
          if (e.autoPop) {
            var result = e.result?.call(e);
            dismiss(context, result: result);
          }
        },
        child: Container(
          width: double.infinity,
          alignment: Alignment.center,
          padding: e.padding,
          decoration: BoxDecoration(
            color: e.color,
            border: Border(
              bottom: BorderSide(color: e.dividerLineColor, width: 0.5),
            ),
          ),
          child: PQText.lines(
            e.text,
            color: e.textColor,
            fontSize: e.fontSize,
            fontWeight: e.fontWeight,
            maxLines: e.maxLines,
          ),
        ),
      ));
    });

    return await showBottomSheet(
      context,
      // SizedBox(height: height, child: Column(children: children)),
      Column(mainAxisSize: MainAxisSize.min, children: children),
      backgroundColor: backgroundColor,
      elevation: elevation,
      barrierColor: barrierColor,
      isScrollControlled: isScrollControlled,
      useRootNavigator: useRootNavigator,
      isDismissible: isDismissible,
      enableDrag: enableDrag,
      routeSettings: routeSettings,
      transitionAnimationController: transitionAnimationController,
      shape: shape,
    );
  }

  static Future showBottomSheet(
    context,
    Widget child, {
    Color? backgroundColor = Colors.white,
    double? elevation,
    Clip? clipBehavior,
    Color? barrierColor,
    bool isScrollControlled = false,
    bool useRootNavigator = false,
    bool isDismissible = true,
    bool enableDrag = true,
    RouteSettings? routeSettings,
    AnimationController? transitionAnimationController,
    ShapeBorder? shape = const RoundedRectangleBorder(
      borderRadius: BorderRadius.vertical(top: Radius.circular(16.0)),
    ),
  }) async {
    return await showModalBottomSheet(
      context: context,
      backgroundColor: backgroundColor,
      elevation: elevation,
      clipBehavior: clipBehavior,
      barrierColor: barrierColor,
      isScrollControlled: isScrollControlled,
      useRootNavigator: useRootNavigator,
      isDismissible: isDismissible,
      enableDrag: enableDrag,
      routeSettings: routeSettings,
      transitionAnimationController: transitionAnimationController,
      shape: shape,
      builder: (context) {
        return SafeArea(
          child: AnimatedPadding(
            padding: MediaQuery.of(context).viewInsets,
            duration: const Duration(milliseconds: 200),
            child: child,
          ),
        );
      },
    );
  }
}
