import 'package:flutter/material.dart';
import 'package:pq_widgets/pq_widgets.dart';

class NormalDialog extends StatelessWidget {
  NormalDialog({
    Key? key,
    this.onCancel,
    this.onSubmit,
    this.title,
    this.content,
    this.cancel,
    this.submit,
    this.titleColor = const Color(0xFF333333),
    this.contentColor = const Color(0xFF666666),
    this.cancelColor = const Color(0xFF999999),
    this.submitColor = const Color(0xFF999999),
    this.backgroundColor = Colors.white,
    BorderRadius? borderRadius,
    this.margin = const EdgeInsets.symmetric(horizontal: 44.0),
  })  : borderRadius = borderRadius ?? BorderRadius.circular(12.0),
        super(key: key);

  final Function()? onCancel;
  final Function()? onSubmit;
  final String? title;
  final String? content;
  final String? cancel;
  final String? submit;
  final Color? titleColor;
  final Color? contentColor;
  final Color? cancelColor;
  final Color? submitColor;

  /// default is `Colors.white`
  final Color backgroundColor;

  /// default is `BorderRadius.circular(12.0)`
  final BorderRadius borderRadius;

  /// default is `EdgeInsets.symmetric(horizontal: 44.0)`
  final EdgeInsets margin;

  bool get hasTitle => title?.isNotEmpty ?? false;
  bool get hasContent => content?.isNotEmpty ?? false;
  bool get hasCancel => cancel?.isNotEmpty ?? false;
  bool get hasSubmit => submit?.isNotEmpty ?? false;

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        Container(
          decoration: BoxDecoration(
            color: backgroundColor,
            borderRadius: borderRadius,
          ),
          padding: EdgeInsets.symmetric(horizontal: 24),
          margin: margin,
          child: Column(children: [_top(), _center(), _bottom()]),
        )
      ],
    );
  }

  Widget _top() {
    if (!hasTitle) return SizedBox.shrink();

    return Container(
      padding: EdgeInsets.only(
        top: 24.0,
        bottom: hasContent ? 0.0 : 24.0,
      ),
      child: PQText(
        title,
        textAlign: TextAlign.center,
        maxLines: 2,
        color: titleColor,
        lineHeight: 27.0,
        fontWeight: FontWeight.bold,
      ),
    );
  }

  Widget _center() {
    if (!hasContent) return SizedBox.shrink();

    return Container(
      padding: EdgeInsets.only(top: hasTitle ? 12.0 : 24.0, bottom: 24.0),
      child: PQText(
        content,
        textAlign: TextAlign.center,
        maxLines: 2,
        color: contentColor,
        fontSize: 15.0,
        lineHeight: 22.0,
      ),
    );
  }

  Widget _bottom() {
    if ((!hasCancel) && (!hasSubmit)) {
      throw "cancel和submit不能都为空";
    }

    Widget _btn(
        String text, Color? color, FontWeight fontWeight, Function()? onTap) {
      return Expanded(
        child: GestureDetector(
          onTap: onTap,
          child: Container(
            alignment: Alignment.center,
            child: PQText(text,
                color: color, fontSize: 16.0, fontWeight: fontWeight),
          ),
        ),
      );
    }

    return Container(
      height: 48.0,
      decoration: BoxDecoration(
        border: Border(
          top: BorderSide(color: Color(0xFFF0F0F0), width: 0.5),
        ),
      ),
      child: Row(
        children: [
          if (cancel?.isNotEmpty ?? false)
            _btn(cancel!, cancelColor, FontWeight.normal, onCancel),
          if ((submit?.isNotEmpty ?? false) || (cancel?.isNotEmpty ?? false))
            Container(width: 0.5, color: Color(0xFFF0F0F0)),
          if (submit?.isNotEmpty ?? false)
            _btn(submit!, submitColor, FontWeight.bold, onSubmit),
        ],
      ),
    );
  }
}
