import 'package:flutter/cupertino.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

/// 间距、间隔、空视图
class PQSize extends StatelessWidget {
  final double width;
  final double height;
  final Widget? child;

  PQSize._(this.width, this.height, {Key? key, this.child}) : super(key: key);

  /// 水平方向
  factory PQSize.h(double width) => PQSize._(width, 0.0);

  /// 垂直方向
  factory PQSize.v(double height) => PQSize._(0.0, height);

  /// 空
  factory PQSize.empty() => PQSize._(0.0, 0.0);

  /// 设置大小
  factory PQSize([double width = 0, double height = 0, Widget? child]) =>
      PQSize._(width, height, child: child);

  /// 根据屏幕的高度进行分配
  factory PQSize.sh(double value) => PQSize._(0.0, value.sh);
  /// 根据屏幕的宽度进行分配
  factory PQSize.sw(double value) => PQSize._(0.0, value.sw);
  ///  根据比例调整高度
  factory PQSize.dh(double value) => PQSize._(0.0, value.h);
  /// 根据比例调整宽度
  factory PQSize.dw(double value) => PQSize._(0.0, value.h);


  @override
  Widget build(BuildContext context) =>
      SizedBox(width: width, height: height, child: child);
}
