import 'package:flutter/material.dart';
import 'pq_font_size.dart';
import 'pq_text_match.dart';


/// 文本框的封装
// ignore: must_be_immutable
class PQText extends StatelessWidget {
  /// text
  String? title;

  /// 文本装饰
  TextDecoration? decoration;

  /// 对齐方式，default is [TextAlign.start]
  TextAlign textAlign;

  /// 最大行数，默认是null
  int? maxLines;

  /// 文本颜色
  Color? color;

  /// 字体大小，默认是 [defaultFontSize]
  double fontSize;

  /// 默认是 [defaultFamily]
  String? fontFamily;

  /// fontWeight
  FontWeight? fontWeight;

  /// 默认使用系统的
  double? wordSpacing;

  /// 默认使用系统的
  double? letterSpacing;

  /// 截断方式
  TextOverflow? overflow;

  double? height;

  /// default is 1
  double? textScaleFactor;

  /// 富文本数据
  List<InlineSpan>? children;

  /// 段落样式
  StrutStyle? strutStyle;

  /// 默认的文本大小
  static PQFontSize defaultFontSize = PQFontSize.f17();

  /// 默认的字体样式
  static String? defaultFontFamily;

  /// 创建Text Widget，默认是显示一行，如果要多行请使用[PQText.lines]，在超出text小部件的宽度的时候会用...结束
  PQText(
    this.title, {
    Key? key,
    this.decoration,
    this.textAlign = TextAlign.start,
    this.maxLines,
    this.color = const Color(0xff000000),
    double? fontSize,
    this.fontFamily,
    this.fontWeight = FontWeight.normal,
    this.wordSpacing,
    this.letterSpacing,
    this.strutStyle,
    this.overflow = TextOverflow.ellipsis,
    this.textScaleFactor = 1,
    double? lineHeight,
  })  : fontSize = fontSize ?? defaultFontSize.fontSize,
        super(key: key) {
    if (lineHeight != null) {
      height = lineHeight / this.fontSize;
    }
  }

  /// 创建Text Widget，默认是显示多行，如果要一行请使用[PQText]
  PQText.lines(
    this.title, {
    Key? key,
    this.decoration,
    this.textAlign = TextAlign.start,
    this.maxLines,
    this.color = const Color(0xff000000),
    double? fontSize,
    this.fontFamily,
    this.fontWeight = FontWeight.normal,
    this.wordSpacing,
    this.letterSpacing,
    this.strutStyle,
    this.overflow,
    this.textScaleFactor = 1,
    double? lineHeight,
  })  : fontSize = fontSize ?? defaultFontSize.fontSize,
        super(key: key) {
    if (lineHeight != null) {
      height = lineHeight / this.fontSize;
    }
  }

  /// 创建Text Widget，默认是显示一行，如果要多行请使用[PQText.richLines]
  PQText.rich(
    this.title, {
    Key? key,
    this.children,
    this.decoration,
    this.textAlign = TextAlign.start,
    this.maxLines,
    this.color = const Color(0xff000000),
    double? fontSize,
    this.fontFamily,
    this.fontWeight = FontWeight.normal,
    this.wordSpacing,
    this.letterSpacing,
    this.strutStyle,
    this.overflow = TextOverflow.ellipsis,
    this.textScaleFactor = 1,
    double? lineHeight,
  })  : fontSize = fontSize ?? defaultFontSize.fontSize,
        super(key: key) {
    if (lineHeight != null) {
      height = lineHeight / this.fontSize;
    }
  }

  /// 创建Text Widget，默认是显示多行，如果要一行请使用[PQText.rich]
  PQText.richLines(this.title,
      {Key? key,
      this.children,
      this.decoration,
      this.textAlign = TextAlign.start,
      this.maxLines,
      this.color = const Color(0xff000000),
      double? fontSize,
      this.fontFamily,
      this.fontWeight = FontWeight.normal,
      this.wordSpacing,
      this.letterSpacing,
      this.strutStyle,
      this.overflow,
      this.textScaleFactor = 1,
      double? lineHeight})
      : fontSize = fontSize ?? defaultFontSize.fontSize,
        super(key: key) {
    if (lineHeight != null) {
      height = lineHeight / this.fontSize;
    }
  }

  /// 通过正则去匹配文字，修改匹配成功的文本样式
  PQText.regexRich(
    String text,
    RegExp regExp,
    TextStyle regExpStyle, {
    Key? key,
    this.decoration,
    this.textAlign = TextAlign.start,
    this.maxLines,
    this.color = const Color(0xff000000),
    this.fontSize = 17,
    this.fontFamily,
    this.fontWeight = FontWeight.normal,
    this.wordSpacing,
    this.letterSpacing,
    this.strutStyle,
    this.overflow = TextOverflow.ellipsis,
    this.textScaleFactor = 1,
    double? lineHeight,
  }) : super(key: key) {
    if (lineHeight != null) {
      height = lineHeight / fontSize;
    }
    title = '';

    final list = YHMatch.regex(regExp, text);
    children = [];
    if (list.isEmpty) {
      title = text;
    }
    list.forEach((element) {
      final start = element.highlight ? element.start + 1 : element.start;
      final end = element.highlight ? element.end - 1 : element.end;
      children!.add(TextSpan(
        text: text.substring(start, end),
        style: element.highlight ? regExpStyle : null,
      ));
    });
  }

  @override
  Widget build(BuildContext context) {

    final style = TextStyle(
      height: height,
      wordSpacing: wordSpacing,
      decoration: decoration ?? TextDecoration.none,
      color: color,
      fontSize: fontSize,
      fontFamily: fontFamily ?? defaultFontFamily,
      fontWeight: fontWeight,
    );

    if (children?.isNotEmpty ?? false) {
      return Text.rich(
        TextSpan(text: title ?? "", children: children),
        textAlign: textAlign,
        maxLines: maxLines,
        overflow: overflow,
        style: style,
        textScaleFactor: textScaleFactor, //设置1，字体大小不随系统改变
      );
    }
    return Text(
      title ?? "",
      textScaleFactor: textScaleFactor,
      //设置1，字体大小不随系统改变
      textAlign: textAlign,
      maxLines: maxLines,
      overflow: overflow,
      style: style,
      strutStyle: strutStyle,
    );
  }
}
